.. WMCore documentation master file

WMCore
======

* **Version**: |version|
* **Last modified**: |today|

.. toctree::
   :maxdepth: 2

   introduction.rst
   changelog.rst
   modules.rst
   references.rst

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
